@@ -106,8 +106,8 @@ def plot_confusion_matrix(y_true, y_pred, title=None, normalize=False, ax=None,
     return ax
 
 
-def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None, figsize=None,
-                   title_fontsize="large", text_fontsize="medium"):
+def plot_roc_curve(y_true, y_probas, title='ROC Curves', curves=('micro', 'macro', 'each_class'),
+                   ax=None, figsize=None, title_fontsize="large", text_fontsize="medium"):
     """Generates the ROC curves for a set of ground truth labels and classifier probability predictions.
 
     Args:
@@ -119,6 +119,10 @@ def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None, figsize=None,
 
         title (string, optional): Title of the generated plot. Defaults to "ROC Curves".
 
+        curves (array-like): A listing of which curves should be plotted on the
+            resulting plot. Defaults to `("micro", "macro", "each_class")`
+            i.e. "micro" for micro-averaged curve, "macro" for macro-averaged curve
+
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
@@ -147,10 +151,13 @@ def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None, figsize=None,
            :align: center
            :alt: ROC Curves
     """
+
+    if 'micro' not in curves and 'macro' not in curves and 'each_class' not in curves:
+        raise ValueError('Invalid argument for curves as it only takes "micro", "macro", or "each_class"')
+
     classes = np.unique(y_true)
     probas = y_probas
-
-    # Compute ROC curve and ROC area for each class
+    
     fpr = dict()
     tpr = dict()
     roc_auc = dict()
@@ -199,17 +206,21 @@ def plot_roc_curve(y_true, y_probas, title='ROC Curves', ax=None, figsize=None,
 
     ax.set_title(title, fontsize=title_fontsize)
 
-    for i in range(len(classes)):
-        ax.plot(fpr[i], tpr[i], lw=2,
-                label='ROC curve of class {0} (area = {1:0.2f})'
-                ''.format(classes[i], roc_auc[i]))
-
-    ax.plot(fpr[micro_key], tpr[micro_key],
-            label='micro-average ROC curve (area = {0:0.2f})'.format(roc_auc[micro_key]),
-            color='deeppink', linestyle=':', linewidth=4)
-    ax.plot(fpr[macro_key], tpr[macro_key],
-            label='macro-average ROC curve (area = {0:0.2f})'.format(roc_auc[macro_key]),
-            color='navy', linestyle=':', linewidth=4)
+    if 'each_class' in curves:
+        for i in range(len(classes)):
+            ax.plot(fpr[i], tpr[i], lw=2,
+                    label='ROC curve of class {0} (area = {1:0.2f})'
+                    ''.format(classes[i], roc_auc[i]))
+        
+    if 'micro' in curves:
+        ax.plot(fpr[micro_key], tpr[micro_key],
+                label='micro-average ROC curve (area = {0:0.2f})'.format(roc_auc[micro_key]),
+                color='deeppink', linestyle=':', linewidth=4)
+      
+    if 'macro' in curves:
+        ax.plot(fpr[macro_key], tpr[macro_key],
+                label='macro-average ROC curve (area = {0:0.2f})'.format(roc_auc[macro_key]),
+                color='navy', linestyle=':', linewidth=4)
 
     ax.plot([0, 1], [0, 1], 'k--', lw=2)
     ax.set_xlim([0.0, 1.0])
@@ -295,7 +306,8 @@ def plot_ks_statistic(y_true, y_probas, title='KS Statistic Plot', ax=None, figs
     return ax
 
 
-def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve', ax=None,
+def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve',
+                                curves=('micro', 'each_class'), ax=None,
                                 figsize=None, title_fontsize="large", text_fontsize="medium"):
     """Generates the Precision Recall Curve for a set of ground truth labels and classifier probability predictions.
 
@@ -306,6 +318,10 @@ def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve'
         y_probas (array-like, shape (n_samples, n_classes)):
             Prediction probabilities for each class returned by a classifier.
 
+        curves (array-like): A listing of which curves should be plotted on the
+            resulting plot. Defaults to `("micro", "each_class")`
+            i.e. "micro" for micro-averaged curve
+
         ax (:class:`matplotlib.axes.Axes`, optional): The axes upon which to plot
             the learning curve. If None, the plot is drawn on a new set of axes.
 
@@ -337,6 +353,9 @@ def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve'
     classes = np.unique(y_true)
     probas = y_probas
 
+    if 'micro' not in curves and 'each_class' not in curves:
+        raise ValueError('Invalid argument for curves as it only takes "micro" or "each_class"')
+
     # Compute Precision-Recall curve and area for each class
     precision = dict()
     recall = dict()
@@ -367,13 +386,18 @@ def plot_precision_recall_curve(y_true, y_probas, title='Precision-Recall Curve'
         fig, ax = plt.subplots(1, 1, figsize=figsize)
 
     ax.set_title(title, fontsize=title_fontsize)
-    for i in range(len(classes)):
-        ax.plot(recall[i], precision[i], lw=2,
-                label='Precision-recall curve of class {0} '
-                      '(area = {1:0.3f})'.format(classes[i], average_precision[i]))
-    ax.plot(recall[micro_key], precision[micro_key], lw=2, color='gold',
-            label='micro-average Precision-recall curve '
-                  '(area = {0:0.3f})'.format(average_precision[micro_key]))
+
+    if 'each_class' in curves:
+        for i in range(len(classes)):
+            ax.plot(recall[i], precision[i], lw=2,
+                    label='Precision-recall curve of class {0} '
+                          '(area = {1:0.3f})'.format(classes[i], average_precision[i]))
+
+    if 'micro' in curves:
+        ax.plot(recall[micro_key], precision[micro_key],
+                label='micro-average Precision-recall curve '
+                      '(area = {0:0.3f})'.format(average_precision[micro_key]),
+                color='navy', linestyle=':', linewidth=4)
 
     ax.set_xlim([0.0, 1.0])
     ax.set_ylim([0.0, 1.05])
